@@ -196,7 +196,9 @@ KNHAPI(knh_intptr_t) knh_bytes_toint(knh_bytes_t t);
 KNHAPI(knh_float_t) knh_bytes_tofloat(knh_bytes_t t);
 KNHAPI(knh_int64_t) knh_bytes_toint64(knh_bytes_t t);
 KNHAPI(String*) new_String__fbcnv(Ctx *ctx, String *s, knh_fbcnv fbcnv, BytesConv *bc);
-KNHAPI(knh_sfp_t*) knh_Closure_finvoke(Ctx *ctx, Closure *c, const char *fmt, ...);
+KNHAPI(void) knh_putsfp(Ctx *ctx, knh_sfp_t *lsfp, int n, Object *obj);
+KNHAPI(void) knh_Closure_invokesfp(Ctx *ctx, Closure *c, knh_sfp_t *lsfp, int argc);
+KNHAPI(knh_sfp_t*) knh_Closure_invokef(Ctx *ctx, Closure *c, const char *fmt, ...);
 KNHAPI(Exception*) new_Exception(Ctx *ctx, String *msg);
 KNHAPI(Exception*) new_Exception__b(Ctx *ctx, knh_bytes_t msg);
 KNHAPI(void) knh_perrno(Ctx *ctx, char *emsg, char *func, char *file, int line);
