@@ -577,6 +577,9 @@ void konoha_initfibo(Ctx *ctx);
 METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
+/* ../src/main/glue.c */
+int knh_fcallback_cmpr(Object *obj, Object *obj2);
+void *konoha_generateCallBackFunc(Ctx *ctx, void *func, Closure *c);
 /* ../src/main/knh_tClass.c */
 void KNH_ACLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
 void KNH_ICLASS(Ctx *ctx, knh_class_t cid, knh_class_t p1);
