@@ -124,7 +124,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_ObjectField_traverse,
 		(knh_fstruct_compareTo)knh_ObjectField_compareTo,
 		(knh_fstruct_hashCode)knh_ObjectField_hashCode,
-		(knh_fstruct_newClass)knh_ObjectField_newClass
+		(knh_fstruct_newClass)knh_ObjectField_newClass,
+		knh_ObjectField_getkey
 	},
 	{
 		"Any", STRUCT_Any, FLAG_Any, 0,
@@ -133,7 +134,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Any_traverse,
 		(knh_fstruct_compareTo)knh_Any_compareTo,
 		(knh_fstruct_hashCode)knh_Any_hashCode,
-		(knh_fstruct_newClass)knh_Any_newClass
+		(knh_fstruct_newClass)knh_Any_newClass,
+		knh_Any_getkey
 	},
 	{
 		"Nue", STRUCT_Nue, FLAG_Nue, 0,
@@ -142,7 +144,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Nue_traverse,
 		(knh_fstruct_compareTo)knh_Nue_compareTo,
 		(knh_fstruct_hashCode)knh_Nue_hashCode,
-		(knh_fstruct_newClass)knh_Nue_newClass
+		(knh_fstruct_newClass)knh_Nue_newClass,
+		knh_Nue_getkey
 	},
 	{
 		"Boolean", STRUCT_Boolean, FLAG_Boolean, 0,
@@ -151,7 +154,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Boolean_traverse,
 		(knh_fstruct_compareTo)knh_Boolean_compareTo,
 		(knh_fstruct_hashCode)knh_Boolean_hashCode,
-		(knh_fstruct_newClass)knh_Boolean_newClass
+		(knh_fstruct_newClass)knh_Boolean_newClass,
+		knh_Boolean_getkey
 	},
 	{
 		"Number", STRUCT_Number, FLAG_Number, 0,
@@ -160,7 +164,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Number_traverse,
 		(knh_fstruct_compareTo)knh_Number_compareTo,
 		(knh_fstruct_hashCode)knh_Number_hashCode,
-		(knh_fstruct_newClass)knh_Number_newClass
+		(knh_fstruct_newClass)knh_Number_newClass,
+		knh_Number_getkey
 	},
 	{
 		"Int", STRUCT_Int, FLAG_Int, 0,
@@ -169,7 +174,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Int_traverse,
 		(knh_fstruct_compareTo)knh_Int_compareTo,
 		(knh_fstruct_hashCode)knh_Int_hashCode,
-		(knh_fstruct_newClass)knh_Int_newClass
+		(knh_fstruct_newClass)knh_Int_newClass,
+		knh_Int_getkey
 	},
 	{
 		"Float", STRUCT_Float, FLAG_Float, 0,
@@ -178,7 +184,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Float_traverse,
 		(knh_fstruct_compareTo)knh_Float_compareTo,
 		(knh_fstruct_hashCode)knh_Float_hashCode,
-		(knh_fstruct_newClass)knh_Float_newClass
+		(knh_fstruct_newClass)knh_Float_newClass,
+		knh_Float_getkey
 	},
 	{
 		"String", STRUCT_String, FLAG_String, 0,
@@ -187,7 +194,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_String_traverse,
 		(knh_fstruct_compareTo)knh_String_compareTo,
 		(knh_fstruct_hashCode)knh_String_hashCode,
-		(knh_fstruct_newClass)knh_String_newClass
+		(knh_fstruct_newClass)knh_String_newClass,
+		knh_String_getkey
 	},
 	{
 		"Bytes", STRUCT_Bytes, FLAG_Bytes, 0,
@@ -196,7 +204,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Bytes_traverse,
 		(knh_fstruct_compareTo)knh_Bytes_compareTo,
 		(knh_fstruct_hashCode)knh_Bytes_hashCode,
-		(knh_fstruct_newClass)knh_Bytes_newClass
+		(knh_fstruct_newClass)knh_Bytes_newClass,
+		knh_Bytes_getkey
 	},
 	{
 		"Tuple2", STRUCT_Tuple2, FLAG_Tuple2, 0,
@@ -205,7 +214,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Tuple2_traverse,
 		(knh_fstruct_compareTo)knh_Tuple2_compareTo,
 		(knh_fstruct_hashCode)knh_Tuple2_hashCode,
-		(knh_fstruct_newClass)knh_Tuple2_newClass
+		(knh_fstruct_newClass)knh_Tuple2_newClass,
+		knh_Tuple2_getkey
 	},
 	{
 		"Range", STRUCT_Range, FLAG_Range, 0,
@@ -214,7 +224,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Range_traverse,
 		(knh_fstruct_compareTo)knh_Range_compareTo,
 		(knh_fstruct_hashCode)knh_Range_hashCode,
-		(knh_fstruct_newClass)knh_Range_newClass
+		(knh_fstruct_newClass)knh_Range_newClass,
+		knh_Range_getkey
 	},
 	{
 		"Array", STRUCT_Array, FLAG_Array, 0,
@@ -223,7 +234,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Array_traverse,
 		(knh_fstruct_compareTo)knh_Array_compareTo,
 		(knh_fstruct_hashCode)knh_Array_hashCode,
-		(knh_fstruct_newClass)knh_Array_newClass
+		(knh_fstruct_newClass)knh_Array_newClass,
+		knh_Array_getkey
 	},
 	{
 		"IArray", STRUCT_IArray, FLAG_IArray, 0,
@@ -232,7 +244,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_IArray_traverse,
 		(knh_fstruct_compareTo)knh_IArray_compareTo,
 		(knh_fstruct_hashCode)knh_IArray_hashCode,
-		(knh_fstruct_newClass)knh_IArray_newClass
+		(knh_fstruct_newClass)knh_IArray_newClass,
+		knh_IArray_getkey
 	},
 	{
 		"FArray", STRUCT_FArray, FLAG_FArray, 0,
@@ -241,7 +254,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_FArray_traverse,
 		(knh_fstruct_compareTo)knh_FArray_compareTo,
 		(knh_fstruct_hashCode)knh_FArray_hashCode,
-		(knh_fstruct_newClass)knh_FArray_newClass
+		(knh_fstruct_newClass)knh_FArray_newClass,
+		knh_FArray_getkey
 	},
 	{
 		"Iterator", STRUCT_Iterator, FLAG_Iterator, sizeof(knh_Iterator_struct),
@@ -250,7 +264,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Iterator_traverse,
 		(knh_fstruct_compareTo)knh_Iterator_compareTo,
 		(knh_fstruct_hashCode)knh_Iterator_hashCode,
-		(knh_fstruct_newClass)knh_Iterator_newClass
+		(knh_fstruct_newClass)knh_Iterator_newClass,
+		knh_Iterator_getkey
 	},
 	{
 		"DictMap", STRUCT_DictMap, FLAG_DictMap, 0,
@@ -259,7 +274,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_DictMap_traverse,
 		(knh_fstruct_compareTo)knh_DictMap_compareTo,
 		(knh_fstruct_hashCode)knh_DictMap_hashCode,
-		(knh_fstruct_newClass)knh_DictMap_newClass
+		(knh_fstruct_newClass)knh_DictMap_newClass,
+		knh_DictMap_getkey
 	},
 	{
 		"DictSet", STRUCT_DictSet, FLAG_DictSet, 0,
@@ -268,7 +284,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_DictSet_traverse,
 		(knh_fstruct_compareTo)knh_DictSet_compareTo,
 		(knh_fstruct_hashCode)knh_DictSet_hashCode,
-		(knh_fstruct_newClass)knh_DictSet_newClass
+		(knh_fstruct_newClass)knh_DictSet_newClass,
+		knh_DictSet_getkey
 	},
 	{
 		"HashMap", STRUCT_HashMap, FLAG_HashMap, sizeof(knh_HashMap_struct),
@@ -277,7 +294,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_HashMap_traverse,
 		(knh_fstruct_compareTo)knh_HashMap_compareTo,
 		(knh_fstruct_hashCode)knh_HashMap_hashCode,
-		(knh_fstruct_newClass)knh_HashMap_newClass
+		(knh_fstruct_newClass)knh_HashMap_newClass,
+		knh_HashMap_getkey
 	},
 	{
 		"HashSet", STRUCT_HashSet, FLAG_HashSet, sizeof(knh_HashSet_struct),
@@ -286,7 +304,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_HashSet_traverse,
 		(knh_fstruct_compareTo)knh_HashSet_compareTo,
 		(knh_fstruct_hashCode)knh_HashSet_hashCode,
-		(knh_fstruct_newClass)knh_HashSet_newClass
+		(knh_fstruct_newClass)knh_HashSet_newClass,
+		knh_HashSet_getkey
 	},
 	{
 		"DictIdx", STRUCT_DictIdx, FLAG_DictIdx, 0,
@@ -295,7 +314,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_DictIdx_traverse,
 		(knh_fstruct_compareTo)knh_DictIdx_compareTo,
 		(knh_fstruct_hashCode)knh_DictIdx_hashCode,
-		(knh_fstruct_newClass)knh_DictIdx_newClass
+		(knh_fstruct_newClass)knh_DictIdx_newClass,
+		knh_DictIdx_getkey
 	},
 	{
 		"Class", STRUCT_Class, FLAG_Class, 0,
@@ -304,7 +324,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Class_traverse,
 		(knh_fstruct_compareTo)knh_Class_compareTo,
 		(knh_fstruct_hashCode)knh_Class_hashCode,
-		(knh_fstruct_newClass)knh_Class_newClass
+		(knh_fstruct_newClass)knh_Class_newClass,
+		knh_Class_getkey
 	},
 	{
 		"ClassStruct", STRUCT_ClassStruct, FLAG_ClassStruct, 0,
@@ -313,7 +334,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_ClassStruct_traverse,
 		(knh_fstruct_compareTo)knh_ClassStruct_compareTo,
 		(knh_fstruct_hashCode)knh_ClassStruct_hashCode,
-		(knh_fstruct_newClass)knh_ClassStruct_newClass
+		(knh_fstruct_newClass)knh_ClassStruct_newClass,
+		knh_ClassStruct_getkey
 	},
 	{
 		"MethodField", STRUCT_MethodField, FLAG_MethodField, 0,
@@ -322,7 +344,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_MethodField_traverse,
 		(knh_fstruct_compareTo)knh_MethodField_compareTo,
 		(knh_fstruct_hashCode)knh_MethodField_hashCode,
-		(knh_fstruct_newClass)knh_MethodField_newClass
+		(knh_fstruct_newClass)knh_MethodField_newClass,
+		knh_MethodField_getkey
 	},
 	{
 		"Method", STRUCT_Method, FLAG_Method, sizeof(knh_Method_struct),
@@ -331,7 +354,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Method_traverse,
 		(knh_fstruct_compareTo)knh_Method_compareTo,
 		(knh_fstruct_hashCode)knh_Method_hashCode,
-		(knh_fstruct_newClass)knh_Method_newClass
+		(knh_fstruct_newClass)knh_Method_newClass,
+		knh_Method_getkey
 	},
 	{
 		"Mapper", STRUCT_Mapper, FLAG_Mapper, sizeof(knh_Mapper_struct),
@@ -340,7 +364,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Mapper_traverse,
 		(knh_fstruct_compareTo)knh_Mapper_compareTo,
 		(knh_fstruct_hashCode)knh_Mapper_hashCode,
-		(knh_fstruct_newClass)knh_Mapper_newClass
+		(knh_fstruct_newClass)knh_Mapper_newClass,
+		knh_Mapper_getkey
 	},
 	{
 		"ClassMap", STRUCT_ClassMap, FLAG_ClassMap, sizeof(knh_ClassMap_struct),
@@ -349,7 +374,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_ClassMap_traverse,
 		(knh_fstruct_compareTo)knh_ClassMap_compareTo,
 		(knh_fstruct_hashCode)knh_ClassMap_hashCode,
-		(knh_fstruct_newClass)knh_ClassMap_newClass
+		(knh_fstruct_newClass)knh_ClassMap_newClass,
+		knh_ClassMap_getkey
 	},
 	{
 		"Closure", STRUCT_Closure, FLAG_Closure, sizeof(knh_Closure_struct),
@@ -358,7 +384,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Closure_traverse,
 		(knh_fstruct_compareTo)knh_Closure_compareTo,
 		(knh_fstruct_hashCode)knh_Closure_hashCode,
-		(knh_fstruct_newClass)knh_Closure_newClass
+		(knh_fstruct_newClass)knh_Closure_newClass,
+		knh_Closure_getkey
 	},
 	{
 		"AffineConv", STRUCT_AffineConv, FLAG_AffineConv, 0,
@@ -367,7 +394,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_AffineConv_traverse,
 		(knh_fstruct_compareTo)knh_AffineConv_compareTo,
 		(knh_fstruct_hashCode)knh_AffineConv_hashCode,
-		(knh_fstruct_newClass)knh_AffineConv_newClass
+		(knh_fstruct_newClass)knh_AffineConv_newClass,
+		knh_AffineConv_getkey
 	},
 	{
 		"IntUnit", STRUCT_IntUnit, FLAG_IntUnit, sizeof(knh_IntUnit_struct),
@@ -376,7 +404,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_IntUnit_traverse,
 		(knh_fstruct_compareTo)knh_IntUnit_compareTo,
 		(knh_fstruct_hashCode)knh_IntUnit_hashCode,
-		(knh_fstruct_newClass)knh_IntUnit_newClass
+		(knh_fstruct_newClass)knh_IntUnit_newClass,
+		knh_IntUnit_getkey
 	},
 	{
 		"FloatUnit", STRUCT_FloatUnit, FLAG_FloatUnit, sizeof(knh_FloatUnit_struct),
@@ -385,7 +414,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_FloatUnit_traverse,
 		(knh_fstruct_compareTo)knh_FloatUnit_compareTo,
 		(knh_fstruct_hashCode)knh_FloatUnit_hashCode,
-		(knh_fstruct_newClass)knh_FloatUnit_newClass
+		(knh_fstruct_newClass)knh_FloatUnit_newClass,
+		knh_FloatUnit_getkey
 	},
 	{
 		"Regex", STRUCT_Regex, FLAG_Regex, 0,
@@ -394,7 +424,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Regex_traverse,
 		(knh_fstruct_compareTo)knh_Regex_compareTo,
 		(knh_fstruct_hashCode)knh_Regex_hashCode,
-		(knh_fstruct_newClass)knh_Regex_newClass
+		(knh_fstruct_newClass)knh_Regex_newClass,
+		knh_Regex_getkey
 	},
 	{
 		"BytesConv", STRUCT_BytesConv, FLAG_BytesConv, sizeof(knh_BytesConv_struct),
@@ -403,7 +434,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_BytesConv_traverse,
 		(knh_fstruct_compareTo)knh_BytesConv_compareTo,
 		(knh_fstruct_hashCode)knh_BytesConv_hashCode,
-		(knh_fstruct_newClass)knh_BytesConv_newClass
+		(knh_fstruct_newClass)knh_BytesConv_newClass,
+		knh_BytesConv_getkey
 	},
 	{
 		"StringUnit", STRUCT_StringUnit, FLAG_StringUnit, sizeof(knh_StringUnit_struct),
@@ -412,7 +444,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_StringUnit_traverse,
 		(knh_fstruct_compareTo)knh_StringUnit_compareTo,
 		(knh_fstruct_hashCode)knh_StringUnit_hashCode,
-		(knh_fstruct_newClass)knh_StringUnit_newClass
+		(knh_fstruct_newClass)knh_StringUnit_newClass,
+		knh_StringUnit_getkey
 	},
 	{
 		"InputStream", STRUCT_InputStream, FLAG_InputStream, sizeof(knh_InputStream_struct),
@@ -421,7 +454,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_InputStream_traverse,
 		(knh_fstruct_compareTo)knh_InputStream_compareTo,
 		(knh_fstruct_hashCode)knh_InputStream_hashCode,
-		(knh_fstruct_newClass)knh_InputStream_newClass
+		(knh_fstruct_newClass)knh_InputStream_newClass,
+		knh_InputStream_getkey
 	},
 	{
 		"OutputStream", STRUCT_OutputStream, FLAG_OutputStream, sizeof(knh_OutputStream_struct),
@@ -430,7 +464,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_OutputStream_traverse,
 		(knh_fstruct_compareTo)knh_OutputStream_compareTo,
 		(knh_fstruct_hashCode)knh_OutputStream_hashCode,
-		(knh_fstruct_newClass)knh_OutputStream_newClass
+		(knh_fstruct_newClass)knh_OutputStream_newClass,
+		knh_OutputStream_getkey
 	},
 	{
 		"Connection", STRUCT_Connection, FLAG_Connection, sizeof(knh_Connection_struct),
@@ -439,7 +474,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Connection_traverse,
 		(knh_fstruct_compareTo)knh_Connection_compareTo,
 		(knh_fstruct_hashCode)knh_Connection_hashCode,
-		(knh_fstruct_newClass)knh_Connection_newClass
+		(knh_fstruct_newClass)knh_Connection_newClass,
+		knh_Connection_getkey
 	},
 	{
 		"ResultSet", STRUCT_ResultSet, FLAG_ResultSet, sizeof(knh_ResultSet_struct),
@@ -448,7 +484,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_ResultSet_traverse,
 		(knh_fstruct_compareTo)knh_ResultSet_compareTo,
 		(knh_fstruct_hashCode)knh_ResultSet_hashCode,
-		(knh_fstruct_newClass)knh_ResultSet_newClass
+		(knh_fstruct_newClass)knh_ResultSet_newClass,
+		knh_ResultSet_getkey
 	},
 	{
 		"Exception", STRUCT_Exception, FLAG_Exception, sizeof(knh_Exception_struct),
@@ -457,7 +494,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Exception_traverse,
 		(knh_fstruct_compareTo)knh_Exception_compareTo,
 		(knh_fstruct_hashCode)knh_Exception_hashCode,
-		(knh_fstruct_newClass)knh_Exception_newClass
+		(knh_fstruct_newClass)knh_Exception_newClass,
+		knh_Exception_getkey
 	},
 	{
 		"ExceptionHandler", STRUCT_ExceptionHandler, FLAG_ExceptionHandler, sizeof(knh_ExceptionHandler_struct),
@@ -466,7 +504,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_ExceptionHandler_traverse,
 		(knh_fstruct_compareTo)knh_ExceptionHandler_compareTo,
 		(knh_fstruct_hashCode)knh_ExceptionHandler_hashCode,
-		(knh_fstruct_newClass)knh_ExceptionHandler_newClass
+		(knh_fstruct_newClass)knh_ExceptionHandler_newClass,
+		knh_ExceptionHandler_getkey
 	},
 	{
 		"Script", STRUCT_Script, FLAG_Script, 0,
@@ -475,7 +514,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Script_traverse,
 		(knh_fstruct_compareTo)knh_Script_compareTo,
 		(knh_fstruct_hashCode)knh_Script_hashCode,
-		(knh_fstruct_newClass)knh_Script_newClass
+		(knh_fstruct_newClass)knh_Script_newClass,
+		knh_Script_getkey
 	},
 	{
 		"NameSpace", STRUCT_NameSpace, FLAG_NameSpace, sizeof(knh_NameSpace_struct),
@@ -484,7 +524,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_NameSpace_traverse,
 		(knh_fstruct_compareTo)knh_NameSpace_compareTo,
 		(knh_fstruct_hashCode)knh_NameSpace_hashCode,
-		(knh_fstruct_newClass)knh_NameSpace_newClass
+		(knh_fstruct_newClass)knh_NameSpace_newClass,
+		knh_NameSpace_getkey
 	},
 	{
 		"System", STRUCT_System, FLAG_System, sizeof(knh_System_struct),
@@ -493,7 +534,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_System_traverse,
 		(knh_fstruct_compareTo)knh_System_compareTo,
 		(knh_fstruct_hashCode)knh_System_hashCode,
-		(knh_fstruct_newClass)knh_System_newClass
+		(knh_fstruct_newClass)knh_System_newClass,
+		knh_System_getkey
 	},
 	{
 		"Context", STRUCT_Context, FLAG_Context, 0,
@@ -502,7 +544,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Context_traverse,
 		(knh_fstruct_compareTo)knh_Context_compareTo,
 		(knh_fstruct_hashCode)knh_Context_hashCode,
-		(knh_fstruct_newClass)knh_Context_newClass
+		(knh_fstruct_newClass)knh_Context_newClass,
+		knh_Context_getkey
 	},
 	{
 		"Token", STRUCT_Token, FLAG_Token, sizeof(knh_Token_struct),
@@ -511,7 +554,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Token_traverse,
 		(knh_fstruct_compareTo)knh_Token_compareTo,
 		(knh_fstruct_hashCode)knh_Token_hashCode,
-		(knh_fstruct_newClass)knh_Token_newClass
+		(knh_fstruct_newClass)knh_Token_newClass,
+		knh_Token_getkey
 	},
 	{
 		"Stmt", STRUCT_Stmt, FLAG_Stmt, sizeof(knh_Stmt_struct),
@@ -520,7 +564,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Stmt_traverse,
 		(knh_fstruct_compareTo)knh_Stmt_compareTo,
 		(knh_fstruct_hashCode)knh_Stmt_hashCode,
-		(knh_fstruct_newClass)knh_Stmt_newClass
+		(knh_fstruct_newClass)knh_Stmt_newClass,
+		knh_Stmt_getkey
 	},
 	{
 		"Asm", STRUCT_Asm, FLAG_Asm, sizeof(knh_Asm_struct),
@@ -529,7 +574,8 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_Asm_traverse,
 		(knh_fstruct_compareTo)knh_Asm_compareTo,
 		(knh_fstruct_hashCode)knh_Asm_hashCode,
-		(knh_fstruct_newClass)knh_Asm_newClass
+		(knh_fstruct_newClass)knh_Asm_newClass,
+		knh_Asm_getkey
 	},
 	{
 		"KLRCode", STRUCT_KLRCode, FLAG_KLRCode, sizeof(knh_KLRCode_struct),
@@ -538,13 +584,14 @@ static knh_StructData_t StructData[] = {
 		(knh_fstruct_traverse)knh_KLRCode_traverse,
 		(knh_fstruct_compareTo)knh_KLRCode_compareTo,
 		(knh_fstruct_hashCode)knh_KLRCode_hashCode,
-		(knh_fstruct_newClass)knh_KLRCode_newClass
+		(knh_fstruct_newClass)knh_KLRCode_newClass,
+		knh_KLRCode_getkey
 	},
 	{NULL}
 };
 
 static knh_ClassData_t ClassData[] = {
-	{"konoha.Object", CLASS_Object, CFLAG_Object, STRUCT_Object, CLASS_Object, 0, 32, 0, knh_Object_fdefault},
+	{"konoha.Object", CLASS_Object, CFLAG_Object, STRUCT_Object, CLASS_Object, 0, 33, 0, knh_Object_fdefault},
 	{"konoha.Any", CLASS_Any, CFLAG_Any, STRUCT_Any, CLASS_Object, 0, 0, 0, knh_Any_fdefault},
 	{"konoha.This", CLASS_This, CFLAG_This, STRUCT_This, CLASS_Any, 0, 0, 0, knh_This_fdefault},
 	{"konoha.Any0", CLASS_Any0, CFLAG_Any0, STRUCT_Any0, CLASS_Any, 0, 0, 0, knh_Any0_fdefault},
@@ -575,7 +622,7 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.Class", CLASS_Class, CFLAG_Class, STRUCT_Class, CLASS_Object, 0, 12, 0, knh_Class_fdefault},
 	{"konoha.ClassStruct", CLASS_ClassStruct, CFLAG_ClassStruct, STRUCT_ClassStruct, CLASS_Object, 0, 0, 0, knh_ClassStruct_fdefault},
 	{"konoha.MethodField", CLASS_MethodField, CFLAG_MethodField, STRUCT_MethodField, CLASS_Object, 0, 0, 0, knh_MethodField_fdefault},
-	{"konoha.Method", CLASS_Method, CFLAG_Method, STRUCT_Method, CLASS_Object, 0, 17, 0, knh_Method_fdefault},
+	{"konoha.Method", CLASS_Method, CFLAG_Method, STRUCT_Method, CLASS_Object, 0, 16, 0, knh_Method_fdefault},
 	{"konoha.Mapper", CLASS_Mapper, CFLAG_Mapper, STRUCT_Mapper, CLASS_Object, 0, 12, 0, knh_Mapper_fdefault},
 	{"konoha.ClassMap", CLASS_ClassMap, CFLAG_ClassMap, STRUCT_ClassMap, CLASS_Object, 0, 1, 0, knh_ClassMap_fdefault},
 	{"konoha.Closure", CLASS_Closure, CFLAG_Closure, STRUCT_Closure, CLASS_Object, 0, 3, 0, knh_Closure_fdefault},
@@ -656,7 +703,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"callcc", FIELDN_callcc},
 	{"ch", FIELDN_ch},
 	{"changeChannel", FIELDN_changeChannel},
-	{"class", FIELDN_class},
 	{"clear", FIELDN_clear},
 	{"close", FIELDN_close},
 	{"concat", FIELDN_concat},
@@ -691,6 +737,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"g", FIELDN_g},
 	{"gCMarked", FIELDN_gCMarked},
 	{"gc", FIELDN_gc},
+	{"geClassTable", FIELDN_geClassTable},
 	{"h", FIELDN_h},
 	{"hasDir", FIELDN_hasDir},
 	{"hasFile", FIELDN_hasFile},
@@ -845,7 +892,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"trim", FIELDN_trim},
 	{"typeof", FIELDN_typeof},
 	{"u", FIELDN_u},
-	{"uRN", FIELDN_uRN},
 	{"urn", FIELDN_urn},
 	{"v", FIELDN_v},
 	{"value", FIELDN_value},
@@ -863,9 +909,6 @@ static knh_FieldNameData_t FieldNameData[] = {
 /* ------------------------------------------------------------------------ */
 
 static knh_MethodFieldData_t MethodFieldData[] = {
-	{MFN_Any_Any_, 1+ 0, TYPE_Any, TYPE_Any, FIELDN_o},
-	{MFN_void_OutputStream_Any, 2+ 0, TYPE_void, TYPE_OutputStream, FIELDN_w, TYPE_Any, FIELDN_o},
-	{MFN_Any, 0+ 0, TYPE_Any},
 	{MFN_nThis_Int, 1+ 0, NNTYPE_This, TYPE_Int, FIELDN_i},
 	{MFN_nThis_nInt, 1+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_n},
 	{MFN_nThis_nAny1_, 1+ 0, NNTYPE_This, NNTYPE_Any1, FIELDN_v},
@@ -892,6 +935,7 @@ static knh_MethodFieldData_t MethodFieldData[] = {
 	{MFN_nInt_Any1, 1+ 0, NNTYPE_Int, TYPE_Any1, FIELDN_v},
 	{MFN_nBoolean_Any1, 1+ 0, NNTYPE_Boolean, TYPE_Any1, FIELDN_v},
 	{MFN_void_ArrayCmp, 1+ 0, TYPE_void, TYPE_ArrayCmp, FIELDN_f},
+	{MFN_void_OutputStream_Any, 2+ 0, TYPE_void, TYPE_OutputStream, FIELDN_w, TYPE_Any, FIELDN_m},
 	{MFN_iAny1, 0+ 0, NNITYPE_Any1},
 	{MFN_nThis_nInt_nInt, 2+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y},
 	{MFN_nThis_nInt_nInt_nInt, 3+ 0, NNTYPE_This, NNTYPE_Int, FIELDN_x, NNTYPE_Int, FIELDN_y, NNTYPE_Int, FIELDN_z},
@@ -1157,7 +1201,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh__Object_opIs, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opIs, 0, MFN_nBoolean_Any, (void*)NULL},
 	{knh__Object_opIsa, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opIsa, 0, MFN_nBoolean_nClass, (void*)NULL},
 	{knh__Object_opTo, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_opTo, 0, MFN_nBoolean_nClass, (void*)NULL},
-	{knh__Object_getClass, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_getClass, 0, MFN_nClass, (void*)NULL},
+	{knh__Object_geClassTable, KNH_FLAG_MF_CONST, CLASS_Object, METHODN_geClassTable, 0, MFN_nClass, (void*)NULL},
 	{knh__Object_isNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNull, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_isNotNull, KNH_FLAG_MF_CONST|KNH_FLAG_MF_NULLBASE, CLASS_Object, METHODN_isNotNull, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Object_opItr, 0, CLASS_Object, METHODN_opItr, 0, MFN_iThis, (void*)NULL},
@@ -1251,8 +1295,8 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Mapper, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Mapper__k},
 	{knh__Method_isAbstract, 0, CLASS_Method, METHODN_isAbstract, 0, MFN_nBoolean, (void*)NULL},
 	{knh__Method_getName, 0, CLASS_Method, METHODN_getName, 0, MFN_nString, (void*)NULL},
-	{knh__Method_getURN, 0, CLASS_Method, METHODN_getURN, 0, MFN_nString, (void*)NULL},
 	{knh__Object_new, KNH_FLAG_MF_VIRTUAL, CLASS_Object, METHODN_new, 0, MFN_nThis, (void*)NULL},
+	{knh__Object_getKey, 0, CLASS_Object, METHODN_getKey, 0, MFN_nString, (void*)NULL},
 	{knh__OutputStream_flush, 0, CLASS_OutputStream, METHODN_flush, 0, MFN_void, (void*)NULL},
 	{knh__OutputStream_clear, 0, CLASS_OutputStream, METHODN_clear, 0, MFN_void, (void*)NULL},
 	{knh__OutputStream_close, 0, CLASS_OutputStream, METHODN_close, 0, MFN_void, (void*)NULL},
