@@ -346,9 +346,9 @@ typedef struct knh_hObject_t {
 	knh_ushort_t magic; knh_flag_t  flag;
 	knh_class_t bcid;   knh_class_t cid;
 	knh_ushort_t ctxid; knh_lock_t  lock;
-#ifdef KNH_HOBJECT_REFC
+//#ifdef KNH_HOBJECT_REFC
 	KNH_MT_VOLATILE knh_uintptr_t refc;
-#endif
+//#endif
 	void *meta;
 } knh_hObject_t ;
 
@@ -384,6 +384,8 @@ typedef struct {
 	knh_sline_t  line;
 } knh_FileLine_t ;
 
+#define knh_Object_data(o)       (((Int*)(o))->n.data)
+
 /* ------------------------------------------------------------------------ */
 /* Thread */
 /* ------------------------------------------------------------------------ */
