@@ -461,10 +461,11 @@ Array *new_Array__subset(Ctx *ctx, Array *a, size_t s, size_t e)
 	}
 	if(s < e) {
 		KNH_ASSERT(e <= a->size);
-		size_t i, newsize = e - s;
+		size_t newsize = e - s;
 		newa->list = (Object**)KNH_MALLOC(ctx, newsize * sizeof(Object*));
 		knh_memcpy(newa->list, &a->list[s], newsize * sizeof(Object*));
 #ifdef KNH_USING_RCGC
+		size_t i;
 		for(i = 0; i < newsize; i++) {
 			knh_Object_RCinc(newa->list[i]);
 		}
