@@ -169,7 +169,7 @@ static METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp)
 
 /* ------------------------------------------------------------------------ */
 
-INLINE static
+ static
 int knh_bytes_equals_(knh_bytes_t base, size_t s, knh_bytes_t target)
 {
 	size_t i;
@@ -217,7 +217,7 @@ static METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
-	knh_int_t n = p_int(sfp[1]);
+	knh_intptr_t n = p_int(sfp[1]);
 	if(n <= 0) {
 		KNH_RETURN(ctx, sfp, TS_EMPTY);
 	}else if(n == 1) {
@@ -226,7 +226,7 @@ static METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
 	else {
 		knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 		knh_cwb_t cwb = new_cwb(ctx);
-		knh_int_t i;
+		knh_intptr_t i;
 		for(i = 0; i < n; i++) {
 			knh_Bytes_write(ctx, cwb.ba, base);
 		}
@@ -604,7 +604,7 @@ void knh_String__s(Ctx *ctx, String *b, OutputStream *w, String *m)
 static
 void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m)
 {
-	int_byte_t quote = '\'';
+	int quote = '\'';
 	if(knh_Object_cid(o) == CLASS_String) quote = '"';
 	knh_putc(ctx, w, quote);
 	knh_bytes_t t = knh_String_tobytes(o);
