@@ -28,6 +28,7 @@
 /* ************************************************************************ */
 
 #include"commons.h"
+#include<konoha/konohac_t.h>
 
 /* ************************************************************************ */
 
@@ -83,6 +84,27 @@ METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp)
 
 /* ------------------------------------------------------------------------ */
 
+KNHAPI(void) knh_putsfp(Ctx *ctx, knh_sfp_t *lsfp, int n, Object *obj)
+{
+	KNH_SETv(ctx, lsfp[n].o, obj);
+	lsfp[n].data = knh_Object_data(obj);
+}
+
+/* ------------------------------------------------------------------------ */
+
+KNHAPI(void) knh_Closure_invokesfp(Ctx *ctx, Closure *c, knh_sfp_t *lsfp, int argc)
+{
+	if((c)->finvoke_1 != knh__Delegate_scall) {
+		TODO();
+		KNH_ABORT();
+	}
+	KNH_MOV(ctx, lsfp[1].o, DP(c)->base);
+	KNH_SCALL(ctx, lsfp, 0, DP(c)->mtd, argc);
+	KNH_LOCALBACK(ctx, lsfp);
+}
+
+/* ------------------------------------------------------------------------ */
+
 //#define _knh_Closure_binvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->bvalue)
 //#define _knh_Closure_iinvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->ivalue)
 //#define _knh_Closure_finvokef(ctx, c, fmt, ...)  ((knh_Closure_invokef(ctx, c, fmt, ## __VA_ARGS__))->fvalue)
@@ -91,7 +113,7 @@ METHOD knh__Closure_callcc(Ctx *ctx, knh_sfp_t *sfp)
 // knh_Closure_finvoke(ctx, c, "oo", sfp[1].o, sfp[2].o)
 // knh_Closure_finvoke(ctx, c, "ii", 1, 2)
 
-KNHAPI(knh_sfp_t*) knh_Closure_finvoke(Ctx *ctx, Closure *c, const char *fmt, ...)
+KNHAPI(knh_sfp_t*) knh_Closure_invokef(Ctx *ctx, Closure *c, const char *fmt, ...)
 {
 	char *p = (char*)fmt;
 	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
@@ -131,13 +153,7 @@ KNHAPI(knh_sfp_t*) knh_Closure_finvoke(Ctx *ctx, Closure *c, const char *fmt, ..
 		}/*switch*/
 	} /* while */
 	va_end(args);
-	DBG2_P("argc=%d", n - 2);
-	if((c)->finvoke_1 != knh__Delegate_scall) {
-		KNH_ABORT();
-	}
-	KNH_MOV(ctx, lsfp[1].o, DP(c)->base);
-	KNH_SCALL(ctx, lsfp, 0, DP(c)->mtd, n - 2);
-	KNH_LOCALBACK(ctx, lsfp);
+	knh_Closure_invokesfp(ctx, c, lsfp, n - 2);
 	return lsfp;
 }
 
@@ -398,7 +414,7 @@ knh_class_t knh_class_Closure(Ctx *ctx, knh_type_t r0, knh_type_t p1, knh_type_t
 	knh_class_t cid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, B(buf));
 	if(cid == CLASS_unknown) {
 		DBG2_P("*** Generating %s ***", buf);
-		konoha_addClosureClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), r0, p1, p2, p3);
+		cid = konoha_addClosureClass(ctx, CLASS_newid, new_String(ctx, B(buf), NULL), r0, p1, p2, p3);
 	}
 	return cid;
 }
