@@ -38,7 +38,7 @@ extern "C" {
 /* ======================================================================== */
 /* [constructors] */
 
-DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_int_t offset)
+DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_intptr_t offset)
 {
 	knh_DictIdx_t *o = (knh_DictIdx_t*)new_hObject(ctx, FLAG_DictIdx, CLASS_DictIdx, CLASS_DictIdx);
 	KNH_INITv(o->terms, new_Array0(ctx, init));
@@ -49,7 +49,7 @@ DictIdx* new_DictIdx0(Ctx *ctx, size_t init, knh_int_t offset)
 
 /* ------------------------------------------------------------------------ */
 
-DictIdx* new_DictIdx0__ignoreCase(Ctx *ctx, size_t init, knh_int_t offset)
+DictIdx* new_DictIdx0__ignoreCase(Ctx *ctx, size_t init, knh_intptr_t offset)
 {
 	DictIdx *o = new_DictIdx0(ctx, init, offset);
 	knh_DictSet_toIgnoreCase(o->termsDictSet);
@@ -125,7 +125,7 @@ knh_index_t knh_DictIdx_add__b(Ctx *ctx, DictIdx *o, knh_bytes_t term)
 /* ------------------------------------------------------------------------ */
 /* @  method String DictIdx.get::fast(Int! index) */
 
-String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid)
+String* knh_DictIdx_get__fast(DictIdx *o, knh_intptr_t termid)
 {
 	size_t n = termid_toarrayn(termid);
 	KNH_ASSERT(0 <= n && n < knh_Array_size(o->terms));
@@ -135,7 +135,7 @@ String* knh_DictIdx_get__fast(DictIdx *o, knh_int_t termid)
 /* ------------------------------------------------------------------------ */
 /* @  method String DictIdx.get(Int! index) */
 
-String* knh_DictIdx_get(Ctx *ctx, DictIdx *o, knh_int_t termid)
+String* knh_DictIdx_get(Ctx *ctx, DictIdx *o, knh_intptr_t termid)
 {
 	size_t n = termid_toarrayn(termid);
 	if(0 <= n && n < knh_Array_size(o->terms)) {
