@@ -40,15 +40,15 @@ extern "C" {
 
 static Script *new_Script(Ctx *ctx, knh_bytes_t nsname)
 {
-	knh_class_t cid = knh_tClass_newId(ctx);
+	knh_class_t cid = knh_ClassTable_newId(ctx);
 	knh_Script_t *o = (Script*)new_Object_init(ctx, FLAG_Script, CLASS_Script, 0);
 	o->h.cid = cid;
 
 	char buf[CLASSNAME_BUFSIZ];
-	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
+	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
 	knh_snprintf(buf, sizeof(buf), "%s.Script", (char*)nsname.buf);
 
-	KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+	KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
 
 	TC->cflag  = CFLAG_Script;
 	TC->oflag  = FLAG_Script;
@@ -61,17 +61,17 @@ static Script *new_Script(Ctx *ctx, knh_bytes_t nsname)
 	TC->bsize  = KNH_SCRIPT_FIELDSIZE;
 	TC->size = TC->bsize * sizeof(knh_Object_t*);
 
-	konoha_setClassName(ctx, cid, new_String(ctx, B(buf), NULL));
+	konoha_seClassTableName(ctx, cid, new_String(ctx, B(buf), NULL));
 	KNH_INITv(TC->cstruct, new_ClassStruct0(ctx, KNH_SCRIPT_FIELDSIZE, KNH_SCRIPT_FIELDSIZE/2));
 
 	KNH_ASSERT(TC->cmap == NULL);
-	KNH_INITv(TC->cmap, ctx->tClass[CLASS_Script].cmap);
+	KNH_INITv(TC->cmap, ctx->share->ClassTable[CLASS_Script].cmap);
 
 	KNH_ASSERT(TC->cspec == NULL);
-	konoha_setClassDefaultValue(ctx, cid, UP(o), NULL);
+	konoha_seClassTableDefaultValue(ctx, cid, UP(o), NULL);
 
 	Method *mtd = new_Method(ctx, 0, cid, METHODN_lambda, NULL);
-	KNH_SETv(ctx, DP(mtd)->mf, MF_Any);
+	KNH_SETv(ctx, DP(mtd)->mf, konoha_findMethodField0(ctx, TYPE_Any));
 	knh_Class_addMethod(ctx, cid, mtd);
 	return o;
 }
@@ -82,7 +82,7 @@ static Script *new_Script(Ctx *ctx, knh_bytes_t nsname)
 //void knh_Script_restart(Ctx *ctx, Script *o)
 //{
 //	knh_class_t cid = o->h.cid;
-//	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
+//	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
 //	int i;
 //	for(i = 0; i < KNH_SCRIPT_FIELDSIZE; i++) {
 //		KNH_SETv(ctx, o->fields[i], KNH_NULL);
