@@ -88,7 +88,7 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 		knh_class_t isupcid = icid;
 		int allchecked = 1;
 		while(isupcid != CLASS_Object) {
-			ClassStruct *cs = ctx->tClass[isupcid].cstruct;
+			ClassStruct *cs = ctx->share->ClassTable[isupcid].cstruct;
 			size_t i;
 			for(i = 0; i < knh_Array_size(cs->methods); i++) {
 				Method *imtd = (Method*)knh_Array_n(cs->methods, i);
@@ -107,12 +107,12 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 					}
 				}
 			}
-			isupcid = ctx->tClass[isupcid].supcid;
+			isupcid = ctx->share->ClassTable[isupcid].supcid;
 		}
 		if(allchecked) {
 			isupcid = icid;
 			while(isupcid != CLASS_Object) {
-				ClassStruct *cs = ctx->tClass[isupcid].cstruct;
+				ClassStruct *cs = ctx->share->ClassTable[isupcid].cstruct;
 				size_t i;
 				for(i = 0; i < knh_Array_size(cs->methods); i++) {
 					Method *imtd = (Method*)knh_Array_n(cs->methods, i);
@@ -129,10 +129,10 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 						}
 					}
 				}
-				isupcid = ctx->tClass[isupcid].supcid;
+				isupcid = ctx->share->ClassTable[isupcid].supcid;
 			}
 			DBG2_P("add interface %s to %s", CLASSN(icid), CLASSN(cid));
-			knh_ClassMap_add(ctx, ctx->tClass[cid].cmap, new_Mapper__interface(ctx, cid, icid));
+			knh_ClassMap_add(ctx, ctx->share->ClassTable[cid].cmap, new_Mapper__interface(ctx, cid, icid));
 		}
 	}
 }
@@ -140,9 +140,9 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 ///* ------------------------------------------------------------------------ */
 //
 //static
-//Object *knh_tClass_fdefault__OBJECT(Ctx *ctx, knh_class_t cid)
+//Object *knh_ClassTable_fdefault__OBJECT(Ctx *ctx, knh_class_t cid)
 //{
-//	return new_Object_init(ctx, ctx->tClass[cid].oflag, cid, 0);
+//	return new_Object_init(ctx, ctx->share->ClassTable[cid].oflag, cid, 0);
 //}
 
 /* ------------------------------------------------------------------------ */
@@ -153,10 +153,10 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	char bufn[CLASSNAME_BUFSIZ];
 	knh_snprintf(bufn, sizeof(bufn), "%s.%s", knh_String_tochar(DP(ns)->nsname), sToken(StmtCLASS_class(stmt)));
 
-	knh_class_t cid  = knh_NameSpace_getClass(ctx, ns, B(bufn));
+	knh_class_t cid  = knh_NameSpace_geClassTable(ctx, ns, B(bufn));
 	if(cid == CLASS_unknown) {
-		cid = knh_tClass_newId(ctx);
-		KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+		cid = knh_ClassTable_newId(ctx);
+		KNH_ASSERT(ctx->share->ClassTable[cid].class_cid == NULL);
 	}
 	else {
 		knh_Asm_perror(ctx, abr, KMSG_EOVERRIDE, CLASSN(cid));
@@ -169,7 +169,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		supcid = CLASS_Object;
 	}
 	else {
-		supcid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
+		supcid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
 		if(supcid == CLASS_unknown) {
 			knh_Asm_perror(ctx, abr, KMSG_UCLASSN, NULL);
 			supcid = CLASS_Object;
@@ -184,7 +184,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 
 	DP(StmtCLASS_class(stmt))->cid = cid;
 
-	knh_tClass_t *TC = (knh_tClass_t*)&(ctx->tClass[cid]);
+	knh_ClassTable_t *TC = (knh_ClassTable_t*)&(ctx->share->ClassTable[cid]);
 	TC->cflag  = knh_StmtCLASS_flag(ctx, stmt);
 	TC->oflag  = KNH_FLAG_CF2OF(TC->cflag);
 	if(SP(StmtCLASS_instmt(stmt))->stt == STT_DONE) {
@@ -198,13 +198,13 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		TC->offset = 0;
 	}else {
 		KNH_ASSERT(supcid < cid);
-		TC->offset = ctx->tClass[supcid].bsize;
+		TC->offset = ctx->share->ClassTable[supcid].bsize;
 	}
 	KNH_ASSERT(TC->class_cid == NULL);
-	konoha_setClassName(ctx, cid, new_String(ctx, B(bufn), NULL));
+	konoha_seClassTableName(ctx, cid, new_String(ctx, B(bufn), NULL));
 	KNH_INITv(TC->cstruct, new_ClassStruct0(ctx, 0, 8));
-	KNH_INITv(TC->cmap, ctx->tClass[CLASS_Any].cmap);
-	konoha_setClassDefaultValue(ctx, cid, KNH_NULL, NULL);
+	KNH_INITv(TC->cmap, ctx->share->ClassTable[CLASS_Any].cmap);
+	konoha_seClassTableDefaultValue(ctx, cid, KNH_NULL, NULL);
 	knh_NameSpace_setLocalName(ctx, ns, cid);
 
 	if(SP(StmtCLASS_interface(stmt))->stt != STT_DONE) {
@@ -212,7 +212,7 @@ int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		int i, n = DP(istmt)->size;
 		for(i = 0; i < n; i++) {
 			Token *tk = DP(stmt)->tokens[i];
-			knh_class_t icid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, tk));
+			knh_class_t icid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, tk));
 			if(icid == CLASS_unknown) {
 				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 				continue;
@@ -263,12 +263,12 @@ int knh_StmtUIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	knh_index_t loc = knh_bytes_rindex(name, '.');
 	if(loc != -1) { /* using Math.sin */
 		if(knh_System_loadPackage(ctx, knh_bytes_first(name, loc))) {
-			knh_class_t newcid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, name);
+			knh_class_t newcid = knh_NameSpace_geClassTable(ctx, knh_rootNameSpace, name);
 			if(newcid == CLASS_unknown) {
 				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 				return 0;
 			}
-			knh_class_t oldcid = knh_NameSpace_getClass(ctx, ns, knh_bytes_last(name, loc+1));
+			knh_class_t oldcid = knh_NameSpace_geClassTable(ctx, ns, knh_bytes_last(name, loc+1));
 			if(oldcid != CLASS_unknown && newcid != oldcid) {
 				KNH_WARNING(ctx, "ovrriding.. %s => %s", CLASSN(oldcid), CLASSN(newcid));
 			}
@@ -313,14 +313,14 @@ void knh_NameSpace_setTagName(Ctx *ctx, NameSpace *o, String *name, knh_class_t
 {
 	KNH_ASSERT(IS_NameSpace(o));
 	KNH_ASSERT_cid(cid);
-	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, name, (knh_uint_t)(cid+1));
+	knh_DictSet_set(ctx, DP(o)->name2cidDictSet, name, (knh_uintptr_t)(cid+1));
 	knh_bytes_t n = knh_String_tobytes(name);
 	knh_index_t loc = knh_bytes_index(n, ':');
 	if(loc != -1) {
 		n = knh_bytes_last(n, loc+1);
 		if(isupper(n.buf[0])) {
 			TODO();
-			knh_DictSet_set(ctx, DP(o)->name2cidDictSet, new_String(ctx, n, name), (knh_uint_t)(cid+1));
+			knh_DictSet_set(ctx, DP(o)->name2cidDictSet, new_String(ctx, n, name), (knh_uintptr_t)(cid+1));
 		}
 	}
 }
@@ -341,7 +341,7 @@ int knh_StmtXCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class
 		cid = bcid;
 	}
 
-	knh_class_t oldcid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, tkclassn));
+	knh_class_t oldcid = knh_NameSpace_geClassTable(ctx, ns, knh_Token_tobytes(ctx, tkclassn));
 	if(oldcid != CLASS_unknown && cid != oldcid) {
 		KNH_WARNING(ctx, "Overriding %s", knh_Token_tobytes(ctx, tkclassn));
 	}
@@ -384,7 +384,7 @@ int knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	knh_bytes_t name = knh_Token_tobytes(ctx, tk);
 	if(SP(tk)->tt == TT_CMETHODN) {
 		knh_index_t loc = knh_bytes_rindex(name, '.');
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, knh_bytes_first(name, loc));
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, knh_bytes_first(name, loc));
 		if(cid == CLASS_unknown) {
 			knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 			return 0;
@@ -397,14 +397,14 @@ int knh_StmtUFUNC_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		knh_NameSpace_setFuncClass(ctx, ns, mn, cid);
 	}
 	else {
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, name);
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, name);
 		if(cid == CLASS_unknown) {
 			knh_Token_perror(ctx, tk, KMSG_UCLASSN);
 			return 0;
 		}
 		else {
 			KNH_ASSERT_cid(cid);
-			Array *a = (ctx->tClass[cid].cstruct)->methods;
+			Array *a = (ctx->share->ClassTable[cid].cstruct)->methods;
 			size_t i;
 			for(i = 0; i < knh_Array_size(a); i++) {
 				Method *mtd = (Method*)knh_Array_n(a, i);
