@@ -162,7 +162,7 @@ int knh_isnewerfile(Ctx *ctx, char *path, char *path2)
 /* ======================================================================== */
 /* [time] */
 
-knh_uinteger_t knh_initseed()
+knh_uint_t knh_initseed()
 {
 	return time(NULL) + getpid();
 }
