@@ -42,6 +42,17 @@ extern "C" {
 /* ======================================================================== */
 /* [malloc] */
 
+#ifdef KNH_DEBUGMODE2
+static int canFree = 1;
+#define DBG_ENABLE_FREE()     canFree = 1
+#define DBG_DISABLE_FREE()    canFree = 0
+#define DBG_ASSERT_FREE()     KNH_ASSERT(canFree)
+#else
+#define DBG_ENABLE_FREE()
+#define DBG_DISABLE_FREE()
+#define DBG_ASSERT_FREE()
+#endif
+
 /* ------------------------------------------------------------------------ */
 
 void *knh_malloc(Ctx *ctx, size_t size)
@@ -62,7 +73,7 @@ void *knh_malloc(Ctx *ctx, size_t size)
 
 void knh_free(Ctx *ctx, void *block, size_t size)
 {
-	DBG2_ASSERT(!knh_Context_isMarking(ctx));
+	DBG_ASSERT_FREE();
 	SECURE_bzero(block, size);
 	free(block);
 	knh_stat_dclUsedMemorySize(ctx, size);
@@ -87,7 +98,7 @@ void *DBG2_malloc(Ctx *ctx, size_t size, char *func)
 
 void DBG2_free(Ctx *ctx, void *p, size_t size, char *func)
 {
-	DBG2_ASSERT(!knh_Context_isMarking(ctx));
+	DBG_ASSERT_FREE();
 	size_t *block = ((size_t*)p) - 1;
 	if(size != block[0]) {
 		fprintf(stderr, "%s: ptr = %p, block.size = %d, free.size=%d", func, p, (int)block[0], (int)size);
@@ -212,6 +223,7 @@ void *knh_fastmalloc(Ctx *ctx, size_t size)
 		Object *o = ctx->unusedObject;
 		((knh_Context_t*)ctx)->unusedObject = (knh_Object_t*)o->ref;
 		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
+		DBG2_ASSERT(!knh_isFastMallocMemory((void*)o));
 		knh_setFastMallocMemory((void*)o);
 		return (void*)o;
 	}
@@ -228,7 +240,7 @@ void *knh_fastmalloc(Ctx *ctx, size_t size)
 
 void knh_fastfree(Ctx *ctx, void *block, size_t size)
 {
-	DBG2_ASSERT(!knh_Context_isMarking(ctx));
+	DBG_ASSERT_FREE();
 	if(size <= KNH_FASTMALLOC_SIZE) {
 		DBG2_ASSERT(knh_isFastMallocMemory(block));
 		knh_unsetFastMallocMemory(block);
@@ -236,6 +248,7 @@ void knh_fastfree(Ctx *ctx, void *block, size_t size)
 		o->ref = ctx->unusedObject;
 		((knh_Context_t*)ctx)->unusedObject = o;
 		((knh_Context_t*)ctx)->unusedObjectSize += 1;
+		o->h.magic = 0;
 	}
 	else {
 		SECURE_bzero(block, size);
@@ -262,9 +275,7 @@ knh_Object_t *new_hObject(Ctx *ctx, knh_flag_t flag, knh_class_t bcid, knh_class
 		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
 		knh_stat_incUsedObjectSize(ctx, 1);
 		o->h.magic = KNH_OBJECT_MAGIC;
-#ifdef KNH_HOBJECT_REFC
-		o->h.refc = KNH_RCGC_INIT;
-#endif
+		knh_Object_RCset(o, KNH_RCGC_INIT);
 		o->h.flag = flag;
 		o->h.bcid = bcid;
 		o->h.cid  = cid;
@@ -291,9 +302,7 @@ knh_Object_t *new_Object_bcid(Ctx *ctx, knh_class_t bcid, int init)
 		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
 		knh_stat_incUsedObjectSize(ctx, 1);
 		o->h.magic = KNH_OBJECT_MAGIC;
-#ifdef KNH_HOBJECT_REFC
-		o->h.refc = KNH_RCGC_INIT;
-#endif
+		knh_Object_RCset(o, KNH_RCGC_INIT);
 		o->h.flag = ctx->share->StructTable[bcid].flag;
 		o->h.bcid = bcid;
 		o->h.cid  = bcid;
@@ -327,9 +336,7 @@ knh_Object_t *new_Object_init(Ctx *ctx, knh_flag_t flag, knh_class_t cid, int in
 		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
 		knh_stat_incUsedObjectSize(ctx, 1);
 		o->h.magic = KNH_OBJECT_MAGIC;
-#ifdef KNH_HOBJECT_REFC
-		o->h.refc = KNH_RCGC_INIT;
-#endif
+		knh_Object_RCset(o, KNH_RCGC_INIT);
 		KNH_ASSERT_cid(cid);
 		knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 		o->h.bcid = bcid;
@@ -353,9 +360,11 @@ knh_Object_t *new_Object_init(Ctx *ctx, knh_flag_t flag, knh_class_t cid, int in
 
 void knh_Object_free(Ctx *ctx, knh_Object_t *o)
 {
+	DBG_ASSERT_FREE();
+#ifdef KNH_USING_RCGC
 	KNH_ASSERT(knh_Object_isRC0(o));
+#endif
 //	DBG2_P("o=%p, sid=%d,%s", o, o->h.bcid, STRUCTN(o->h.bcid));
-//	DBG2_ABORT();
 	if(unlikely(o->h.magic == 0)) return;
 	o->h.magic = 0;
 	ctx->share->StructTable[o->h.bcid].ftraverse(ctx, o, knh_Object_sweep);
@@ -398,14 +407,9 @@ KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid)
 		knh_Object_t *o = ctx->unusedObject;
 		((knh_Context_t*)ctx)->unusedObject = (knh_Object_t*)o->ref;
 		((knh_Context_t*)ctx)->unusedObjectSize -= 1;
-
-#ifdef KNH_STATMODE1
-		knh_statUsedObjectSize++;
-#endif
+		knh_stat_incUsedObjectSize(ctx, 1);
 		o->h.magic = KNH_OBJECT_MAGIC;
-#ifdef KNH_HOBJECT_REFC
-		o->h.refc = KNH_RCGC_INIT;
-#endif
+		knh_Object_RCset(o, KNH_RCGC_INIT);
 		o->h.flag = FLAG_Float;
 		o->h.bcid = ctx->share->ClassTable[cid].bcid;
 		o->h.cid  = cid;
@@ -420,59 +424,29 @@ KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid)
 
 /* ========================================================================= */
 
-#define BSHIFT ((KONOHA_PAGESIZE / sizeof(knh_Object_t)) / sizeof(knh_uint_t))
+#define BSHIFT ((KONOHA_PAGESIZE / sizeof(knh_Object_t)) / (sizeof(knh_uintptr_t) * 8))
 
-///* ------------------------------------------------------------------------ */
-//
-//static void knh_Object_setGCMark(void *p)
-//{
-//	knh_uint_t *b = (void*)((((knh_uint_t)p) / KONOHA_PAGESIZE) * KONOHA_PAGESIZE);
-//	b = b + BSHIFT;
-//	int n = ((knh_uint_t)p % KONOHA_PAGESIZE) / sizeof(knh_Object_t);
-//	int x = n/(sizeof(knh_uint_t)*8);
-//	knh_uint_t mask = 1 << (n % (sizeof(knh_uint_t)*8));
-//	b[x] = b[x] & mask;
-//}
-//
-///* ------------------------------------------------------------------------ */
-//
-//static void knh_Object_unsetGCMark(void *p)
-//{
-//	knh_uint_t *b = (void*)((((knh_uint_t)p) / KONOHA_PAGESIZE) * KONOHA_PAGESIZE);
-//	b = b + BSHIFT;
-//	int n = ((knh_uint_t)p % KONOHA_PAGESIZE) / sizeof(knh_Object_t);
-//	int x = n/(sizeof(knh_uint_t)*8);
-//	knh_uint_t mask = 1 << (n % (sizeof(knh_uint_t)*8));
-//	b[x] = b[x] & ~(mask);
-//}
-//
-///* ------------------------------------------------------------------------ */
-//
-//static int knh_Object_isGCMarked(void *p)
-//{
-//	knh_uint_t *b = (void*)((((knh_uint_t)p) / KONOHA_PAGESIZE) * KONOHA_PAGESIZE);
-//	b = b + BSHIFT;
-//	int n = ((knh_uint_t)p % KONOHA_PAGESIZE) / sizeof(knh_Object_t);
-//	int x = n/(sizeof(knh_uint_t)*8);
-//	knh_uint_t mask = 1 << (n % (sizeof(knh_uint_t)*8));
-//	return (b[x] & mask == mask);
-//}
+static int mcount = 0;
 
 /* ------------------------------------------------------------------------ */
 
 void knh_Object_mark1(Ctx *ctx, Object *o)
 {
 	if(IS_Context(o)) {
+		//DBG2_P("marked %p, cid=%d,%s", o, knh_Object_cid(o), CLASSN(knh_Object_cid(o)));
 		knh_Object_traverse(ctx, o, knh_Object_mark1);
 	}
 	else {
+		DBG2_ASSERT(o->h.magic == KNH_OBJECT_MAGIC);
+		DBG2_ASSERT(!knh_isFastMallocMemory((void*)o));
 		knh_uintptr_t *b = (void*)((((knh_uintptr_t)o) / KONOHA_PAGESIZE) * KONOHA_PAGESIZE);
 		b = b + BSHIFT;
 		int n = ((knh_uintptr_t)o % KONOHA_PAGESIZE) / sizeof(knh_Object_t);
 		int x = n/(sizeof(knh_uintptr_t)*8);
 		knh_uintptr_t mask = 1 << (n % (sizeof(knh_uintptr_t)*8));
 		if(!((b[x] & mask) == mask)) {
-			DBG2_P("marked %p, cid=%d,%s", o, knh_Object_cid(o), CLASSN(knh_Object_cid(o)));
+			//DBG2_P("marked %p, cid=%d,%s", o, knh_Object_cid(o), CLASSN(knh_Object_cid(o)));
+			mcount++;
 			b[x] = b[x] | mask;
 			knh_Object_traverse(ctx, o, knh_Object_mark1);
 		}
@@ -494,7 +468,7 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int tindex, size = (int)(ctx->share->ObjectPageTableSize);
 
-	DBG2_P("*** STARTING GC (+%d) ***", (int)(BSHIFT));
+	DBG_P("*** STARTING GC (+%d) ***", (int)(BSHIFT));
 	for(tindex = 0; tindex < size; tindex++) {
 		void *t = ctx->share->ObjectPageTable[tindex].thead;
 
@@ -507,18 +481,20 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 			knh_uintptr_t *b = (knh_uintptr_t*)t;
 			int i;
 			for(i = 0; i < BSHIFT; i++) {
-				b[i + BSHIFT] = 0 ;/*b[i];*/
+				b[i + BSHIFT] = b[i];
 			}
 			t += KONOHA_PAGESIZE;
 		}
 	}
 
-	DBG2_P("***** marking .. ******");
-	knh_Context_setMarking(ctx, 1);
+	DBG_P("***** Marking .. ******");
+	DBG_DISABLE_FREE();
+	mcount = 0;
 	konoha_traverse(ctx, knh_Object_mark1);
-	knh_Context_setMarking(ctx, 0);
+	DBG_ENABLE_FREE();
+	DBG_P("Marked %d/%d objects", mcount, ctx->stat->usedObjectSize);
 
-	DBG2_P("***** sweeping .. ******");
+	DBG_P("***** Sweeping .. ******");
 	size_t cnt = 0;
 	knh_ftraverse fsweep = ctx->fsweep;
 	((Context*)ctx)->fsweep = knh_Object_finalSweep;
@@ -534,24 +510,33 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 		while(t + KONOHA_PAGESIZE < max) {
 			knh_uintptr_t *b = ((knh_uintptr_t*)t) + BSHIFT;
 			int i;
-			for(i = 1; i < KONOHA_PAGESIZE / sizeof(knh_Object_t); i++) {
+			for(i = 1; i < (KONOHA_PAGESIZE / sizeof(knh_Object_t)); i++) {
 				int x = i/(sizeof(knh_uintptr_t)*8);
 				knh_uintptr_t mask = 1 << (i % (sizeof(knh_uintptr_t)*8));
 				if((b[x] & mask) == mask) continue;
 				knh_Object_t *o = t + i;
-#ifdef KNH_HOBJECT_REFC
-				o->h.refc = 0;
-#endif
-				knh_Object_free(ctx, o);
+				DBG2_ASSERT(!knh_isFastMallocMemory((void*)o));
+				if(o->h.magic != KNH_OBJECT_MAGIC) continue;
+				knh_Object_RCset(o, 0);
+				DBG2_P("i=%d, x=%d, o=%p, cid=%s(%d)", i, x, o, CLASSN(o->h.bcid), o->h.bcid);
+				//knh_Object_free(ctx, o);
 				cnt++;
 			}
 			t += KONOHA_PAGESIZE;
 		}
 	}
 	((Context*)ctx)->fsweep = fsweep;
-	DBG2_P("**** collected %d object(s) ****", (int)cnt);
+	DBG_P("**** Collected %d object(s) ****", (int)cnt);
 }
 
+/* ------------------------------------------------------------------------ */
+
+void knh_System_gc(Ctx *ctx)
+{
+	knh__System_gc(ctx, NULL);
+}
+
+
 /* ------------------------------------------------------------------------ */
 
 void knh_Object_RCsweep(Ctx *ctx, Object *o)
