@@ -90,7 +90,7 @@ KNHAPI_(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp)
 
 ///* ------------------------------------------------------------------------ */
 //
-//INLINE
+//
 //Method *knh_stackf_getMethod(Ctx *ctx, Object **sf)
 //{
 //	KNH_ASSERT(IS_Method(sf[-1]));
@@ -100,7 +100,7 @@ KNHAPI_(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* [delta] */
 
-//INLINE
+//
 //Struct *knh_stackf_structDelta(Ctx *ctx, Object **sf)
 //{
 //	KNH_ASSERT(IS_Method(sf[-1]));
@@ -195,7 +195,7 @@ KNHAPI(void) knh_sfp_sformat(Ctx *ctx, knh_sfp_t *lsfp, Method *mtd, OutputStrea
 
 KNHAPI(void) knh_sfp_format(Ctx *ctx, knh_sfp_t *sfp, knh_methodn_t mn, OutputStream *w, Any *m)
 {
-	knh_sfp_sformat(ctx, sfp, knh_tMethod_findMT(ctx, knh_Object_cid(sfp[0].o), mn), w, m);
+	knh_sfp_sformat(ctx, sfp, konoha_lookupFormatter(ctx, knh_Object_cid(sfp[0].o), mn), w, m);
 }
 
 /* ------------------------------------------------------------------------ */
